@@ -15,7 +15,7 @@ def grade_entropy(X):
     return entropy
 
 # TODO: Add Bessel correction
-def minkowski_deviation(x: np.ndarray, order=2) -> float:
+def minkowski_deviation(x: np.ndarray, order=2) -> np.float64:
     '''
     Calculates the Minkowski deviation of
     order p. When the order = 2, it is the
@@ -28,7 +28,7 @@ def minkowski_deviation(x: np.ndarray, order=2) -> float:
     result = np.power(result, 1 / order)
     return result
 
-def reflective_correlation(X: np.ndarray) -> float:
+def reflective_correlation(X: np.ndarray) -> np.float64:
     '''
     Calculates the n-ary reflective correlation coefficient.
     When given an m x 2 data matrix, it is equivalent to the
@@ -61,7 +61,7 @@ def reflective_correlation(X: np.ndarray) -> float:
     r = numerator / denominator
     return r
 
-def pearson_correlation(X: np.ndarray) -> float:
+def pearson_correlation(X: np.ndarray) -> np.float64:
     '''
     This function calculates the n-ary Pearson's r correlation
     coefficient. When given an m x 2 data matrix, it is equivalent
@@ -88,7 +88,7 @@ def pearson_correlation(X: np.ndarray) -> float:
     r = reflective_correlation(transform)
     return r
 
-def circular_correlation(X: np.ndarray) -> float:
+def circular_correlation(X: np.ndarray) -> np.float64:
     '''
     This function calculates the n-ary circular correlation
     coefficient. When given an m x 2 data matrix, it is equivalent
@@ -115,52 +115,56 @@ def circular_correlation(X: np.ndarray) -> float:
     r = reflective_correlation(transform)
     return r
 
-##def spearman_correlation(X: np.ndarray, method='average') -> float:
-##    '''
-##    This function calculates the n-ary Spearman correlation
-##    coefficient. When given an m x 2 data matrix, it is equivalent
-##    to the Spearman's Rho correlation coefficient.
-##
-##    The available data ranking options are directly from `scipy.stats.rankdata`.
-##    
-##    Parameters
-##    ----------
-##        X : array_like
-##            m x n data matrix.
-##        method : {'average', 'min', 'max', 'dense', 'ordinal'}, optional
-##            The method used to assign ranks to tied elements.
-##            The following methods are available (default is 'average'):
-##          * 'average': The average of the ranks that would have been assigned to
-##            all the tied values is assigned to each value.
-##          * 'min': The minimum of the ranks that would have been assigned to all
-##            the tied values is assigned to each value.  (This is also
-##            referred to as "competition" ranking.)
-##          * 'max': The maximum of the ranks that would have been assigned to all
-##            the tied values is assigned to each value.
-##          * 'dense': Like 'min', but the rank of the next highest element is
-##            assigned the rank immediately after those assigned to the tied
-##            elements.
-##          * 'ordinal': All values are given a distinct rank, corresponding to
-##            the order that the values occur in `a`.
-##
-##    Returns
-##    -------
-##        : float
-##            Spearman's correlation coefficient.
-##            
-##    References
-##    ----------
-##    .. [1] "Spearman%27s_rank_correlation_coefficient", https://en.wikipedia.org/wiki/Spearman%27s_rank_correlation_coefficient
-##    .. [2] "scipy.stats.rankdata", https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.rankdata.html
-##
-##    '''
-##    transform = rankdata(X, axis=0, method=method)
-##    transform = transform - np.mean(transform, axis=0)
-##    return reflective_correlation(transform)
+def spearman_correlation(X: np.ndarray, method='average') -> np.float64:
+    '''
+    This function calculates the n-ary Spearman correlation
+    coefficient. When given an m x 2 data matrix, it is equivalent
+    to the Spearman's Rho correlation coefficient.
+
+    The available data ranking options are directly from `scipy.stats.rankdata`.
+    
+    Parameters
+    ----------
+        X : array_like
+            m x n data matrix.
+        method : {'average', 'min', 'max', 'dense', 'ordinal'}, optional
+            The method used to assign ranks to tied elements.
+            The following methods are available (default is 'average'):
+          * 'average': The average of the ranks that would have been assigned to
+            all the tied values is assigned to each value.
+          * 'min': The minimum of the ranks that would have been assigned to all
+            the tied values is assigned to each value.  (This is also
+            referred to as "competition" ranking.)
+          * 'max': The maximum of the ranks that would have been assigned to all
+            the tied values is assigned to each value.
+          * 'dense': Like 'min', but the rank of the next highest element is
+            assigned the rank immediately after those assigned to the tied
+            elements.
+          * 'ordinal': All values are given a distinct rank, corresponding to
+            the order that the values occur in `a`.
+
+    Returns
+    -------
+        : float
+            Spearman's correlation coefficient.
+            
+    References
+    ----------
+    .. [1] "Spearman%27s_rank_correlation_coefficient", https://en.wikipedia.org/wiki/Spearman%27s_rank_correlation_coefficient
+    .. [2] "scipy.stats.rankdata", https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.rankdata.html
+
+    See Also
+    --------
+    scipy.stats.rankdata
+    '''
+    transform = rankdata(X, axis=0, method=method)
+    transform = transform - np.mean(transform, axis=0)
+    return reflective_correlation(transform)
 
 # TODO: Implement
-def angular_disimilarity(X: np.ndarray) -> float:
+def angular_disimilarity(X: np.ndarray) -> np.float64:
     '''
+    .. warn: Not implemented yet.
     Computes the n-ary angular disimilarity.
     When given an m x 2 data matrix, it is equivalent
     to the angular distance.
@@ -172,8 +176,9 @@ def angular_disimilarity(X: np.ndarray) -> float:
     '''
 
 # TODO: Implement 
-def correlation_ratio(X: np.ndarray, y: np.ndarray) -> float:
+def correlation_ratio(X: np.ndarray, y: np.ndarray) -> np.float64:
     '''
+    .. warn: Not implemented yet.
     This function calculates the n-ary correlation ratio of a
     collection of response variables given their classes. The
     classic Fisher's correlation ratio is a special case.
@@ -196,7 +201,7 @@ def correlation_ratio(X: np.ndarray, y: np.ndarray) -> float:
     classes = set(y)
     partitions_X = [X[y == c] for c in classes]
 
-def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> float:
+def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> np.float64:
     '''
     Misiak's n-inner correlation coefficient.
 
@@ -226,7 +231,7 @@ def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> float:
     result = numerator / denominator
     return result
 
-def multisemideviation(X: np.ndarray, p=1) -> float:
+def multisemideviation(X: np.ndarray, p=1) -> np.float64:
     '''
     This function calculates the multisemideviation
     which is the multisemimetric between a collection
@@ -256,12 +261,13 @@ def multisemideviation(X: np.ndarray, p=1) -> float:
     result = np.power(result, 1/p)
     return result
 
-# TODO: Implement math
-def taylor_correlation(X: np.ndarray) -> float:
+def taylor_correlation(X: np.ndarray) -> np.float64:
     '''
+    Taylor 2020 correlation
+
     References
     ----------
-    .. [1] https://arxiv.org/abs/2003.02561
+    .. [1] Taylor, BM. 2020. "A Multi-Way Correlation Coefficient", https://arxiv.org/abs/2003.02561
     '''
     d = X.shape[1]
     result = np.corrcoef(X)
@@ -295,7 +301,7 @@ def trencevski_melceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
     result = numerator / denominator
     return result
 
-def wang_zheng_correlation(X: np.ndarray) -> float:
+def wang_zheng_correlation(X: np.ndarray) -> np.float64:
     '''
     References
     ----------
