@@ -53,6 +53,27 @@ def std(f, t, a, b):
     return sympy.sqrt(1/(b-a) * sympy.integrate(f, (t,a,b)))
 
 def pdev(f, t, a, b, p=2):
+    '''
+    Symbolically computes the definite
+    integral representing the Minkowski deviation of
+    order p of a function using uniform probability measure.
+
+    Parameters
+    ----------
+    f: SymPy expression.
+        Function to be integrated.
+    t: `sympy.core.symbol.Symbol`.
+        Independent variable to be integrated with respect to.
+    a: Undefined.
+        Lower bound of integration.
+    b: Undefined.
+        Upper bound of integration.
+
+    Returns
+    -------
+    result: SymPy expression.
+        Definite Minkowski deviation of order p of function over given interval.
+    '''
     f = (sympy.Abs(sympy.sympify(f) - mean(f, t, a, b)))**p
     return (1/(b-a) * sympy.integrate(f, (t,a,b)))**(1/p)
 
